@@ -126,15 +126,15 @@ void usage()
 "   -R                   The host language is Ruby\n"
 "   -A                   The host language is C#\n"
 "   -O                   The host language is OCaml\n"
-"line directives: (C/D/Ruby/C#)\n"
+"line directives: (C/D/Ruby/C#/OCaml)\n"
 "   -L                   Inhibit writing of #line directives\n"
-"code style: (C/D/Java/Ruby/C#)\n"
+"code style: (C/D/Java/Ruby/C#/OCaml)\n"
 "   -T0                  Table driven FSM (default)\n"
-"code style: (C/D/Ruby/C#)\n"
+"code style: (C/D/Ruby/C#/OCaml)\n"
 "   -T1                  Faster table driven FSM\n"
 "   -F0                  Flat table driven FSM\n"
 "   -F1                  Faster flat table-driven FSM\n"
-"code style: (C/D/C#)\n"
+"code style: (C/D/C#/OCaml)\n"
 "   -G0                  Goto-driven FSM\n"
 "   -G1                  Faster goto-driven FSM\n"
 "code style: (C/D)\n"
