@@ -1,5 +1,5 @@
 /*
- *  Copyright 2005-2007 Adrian Thurston <thurston@cs.queensu.ca>
+ *  Copyright 2005-2007 Adrian Thurston <thurston@complang.org>
  */
 
 /*  This file is part of Ragel.
@@ -19,18 +19,21 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA 
  */
 
-#ifndef _XMLDOTGEN_H
-#define _XMLDOTGEN_H
+#ifndef _XMLCODEGEN_H
+#define _XMLCODEGEN_H
 
 #include <iostream>
 #include "avltree.h"
 #include "fsmgraph.h"
 #include "parsedata.h"
+#include "redfsm.h"
 
 /* Forwards. */
 struct TransAp;
 struct FsmAp;
 struct ParseData;
+struct GenInlineList;
+struct CodeGenData;
 
 struct RedActionTable
 :
@@ -76,14 +79,29 @@ struct NextRedTrans
 	}
 };
 
-class XMLCodeGen
+struct GenBase
+{
+	GenBase( char *fsmName, ParseData *pd, FsmAp *fsm );
+
+	void appendTrans( TransListVect &outList, Key lowKey, Key highKey, TransAp *trans );
+	void reduceActionTables();
+
+	char *fsmName;
+	ParseData *pd;
+	FsmAp *fsm;
+
+	ActionTableMap actionTableMap;
+	int nextActionTableId;
+};
+
+class XMLCodeGen : protected GenBase
 {
 public:
 	XMLCodeGen( char *fsmName, ParseData *pd, FsmAp *fsm, std::ostream &out );
+
 	void writeXML( );
 
 private:
-	void appendTrans( TransListVect &outList, Key lowKey, Key highKey, TransAp *trans );
 	void writeStateActions( StateAp *state );
 	void writeStateList();
 	void writeStateConditions( StateAp *state );
@@ -97,7 +115,6 @@ private:
 	void writeNext( InlineItem *item );
 	void writeNextExpr( InlineItem *item );
 	void writeEntry( InlineItem *item );
-	void writeLmSetActId( InlineItem *item );
 	void writeLmOnLast( InlineItem *item );
 	void writeLmOnNext( InlineItem *item );
 	void writeLmOnLagBehind( InlineItem *item );
@@ -110,7 +127,6 @@ private:
 	void writeActionList();
 	void writeActionTableList();
 	void reduceTrans( TransAp *trans );
-	void reduceActionTables();
 	void writeTransList( StateAp *state );
 	void writeEofTrans( StateAp *state );
 	void writeTrans( Key lowKey, Key highKey, TransAp *defTrans );
@@ -119,13 +135,58 @@ private:
 	void writeMachine();
 	void writeActionExec( InlineItem *item );
 
-	char *fsmName;
-	ParseData *pd;
-	FsmAp *fsm;
 	std::ostream &out;
-	ActionTableMap actionTableMap;
-	int nextActionTableId;
 };
 
+class BackendGen : protected GenBase
+{
+public:
+	BackendGen( char *fsmName, ParseData *pd, FsmAp *fsm, CodeGenData *cgd );
+	void makeBackend( );
 
-#endif /* _XMLDOTGEN_H */
+private:
+	void makeGenInlineList( GenInlineList *outList, InlineList *inList );
+	void makeKey( GenInlineList *outList, Key key );
+	void makeText( GenInlineList *outList, InlineItem *item );
+	void makeLmOnLast( GenInlineList *outList, InlineItem *item );
+	void makeLmOnNext( GenInlineList *outList, InlineItem *item );
+	void makeLmOnLagBehind( GenInlineList *outList, InlineItem *item );
+	void makeActionExec( GenInlineList *outList, InlineItem *item );
+	void makeLmSwitch( GenInlineList *outList, InlineItem *item );
+	void makeSetTokend( GenInlineList *outList, long offset );
+	void makeSetAct( GenInlineList *outList, long lmId );
+	void makeSubList( GenInlineList *outList, InlineList *inlineList, 
+			GenInlineItem::Type type );
+	void makeTargetItem( GenInlineList *outList, NameInst *nameTarg, GenInlineItem::Type type );
+	void makeExecGetTokend( GenInlineList *outList );
+	void makeExports();
+	void makeMachine();
+	void makeActionList();
+	void makeAction( Action *action );
+	void makeActionTableList();
+	void makeConditions();
+	void makeEntryPoints();
+	bool makeNameInst( std::string &out, NameInst *nameInst );
+	void makeStateList();
+
+	void makeStateActions( StateAp *state );
+	void makeEofTrans( StateAp *state );
+	void makeStateConditions( StateAp *state );
+	void makeTransList( StateAp *state );
+	void makeTrans( Key lowKey, Key highKey, TransAp *trans );
+
+	void close_ragel_def();
+
+	CodeGenData *cgd;
+
+	/* Collected during parsing. */
+	int curAction;
+	int curActionTable;
+	int curTrans;
+	int curState;
+	int curCondSpace;
+	int curStateCond;
+
+};
+
+#endif
